@@ -10,7 +10,7 @@ from python_framework.api.src.service import SqlAlchemyProxy
 from python_framework.api.src.service import Security
 from python_framework.api.src.service import SchedulerManager
 from python_framework.api.src.service.openapi import OpenApiManager
-from python_framework.api.src.converter.static import ConverterStatic
+from python_framework.api.src.constant import ConfigurationKeyConstant
 
 DOT_PY = '.py'
 
@@ -105,10 +105,10 @@ def addGlobalsTo(apiInstance) :
     apiInstance.globals = FlaskManager.getGlobals()
     apiInstance.globals.api = apiInstance
     apiInstance.bindResource = FlaskManager.bindResource
-    apiInstance.scheme = apiInstance.globals.getApiSetting(ConverterStatic.API_SERVER_SCHEME)
-    apiInstance.host = apiInstance.globals.getApiSetting(ConverterStatic.API_SERVER_HOST)
-    apiInstance.port = apiInstance.globals.getApiSetting(ConverterStatic.API_SERVER_PORT)
-    apiInstance.baseUrl = apiInstance.globals.getApiSetting(ConverterStatic.API_SERVER_BASE_URL)
+    apiInstance.scheme = apiInstance.globals.getApiSetting(ConfigurationKeyConstant.API_SERVER_SCHEME)
+    apiInstance.host = apiInstance.globals.getApiSetting(ConfigurationKeyConstant.API_SERVER_HOST)
+    apiInstance.port = apiInstance.globals.getApiSetting(ConfigurationKeyConstant.API_SERVER_PORT)
+    apiInstance.baseUrl = apiInstance.globals.getApiSetting(ConfigurationKeyConstant.API_SERVER_BASE_URL)
 
 @Function
 def initialize(
@@ -128,7 +128,7 @@ def initialize(
     addGlobalsTo(api)
     OpenApiManager.newDocumentation(api, app)
     SchedulerManager.addScheduler(api, app)
-    securityKey = api.globals.getApiSetting(ConverterStatic.API_SECURITY_SECRET)
+    securityKey = api.globals.getApiSetting(ConfigurationKeyConstant.API_SECURITY_SECRET)
     if SettingHelper.LOCAL_ENVIRONMENT == SettingHelper.getActiveEnvironment() :
         log.setting(initialize, f'JWT secret: {securityKey}')
     api.jwt = Security.getJwtMannager(app, securityKey)
